@@ -102,6 +102,10 @@ class Settings:
     def FLAVIUS_API_PICKUP_LOCATION_DELETE(self):
         return getattr(settings, "FLAVIUS_API_PICKUP_LOCATION_DELETE", 'api/pickup_location_delete.php')
 
+    @property
+    def FLAVIUS_API_PICKUP_LOCATION_FILE_UPLOAD(self):
+        return getattr(settings, "FLAVIUS_API_PICKUP_LOCATION_FILE_UPLOAD", 'api/pickup_location_upload_location_image')
+
     @property
     def FLAVIUS_API_PICKUP_TIME_LIST(self):
         return getattr(settings, "FLAVIUS_API_PICKUP_TIME_LIST", 'api/pickup_time_list.php')
